# Summary of 1 files

### input_data_already_processed in 1 LFNs

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) |
| --------- | --- | ------ | ---- | -------- | ---------- |
| `256909` | `LFN:/lhcb/LHCb/Collision18/BHADRON.MDST/00092561/0000/00092561_00007811_1.bhadron.mdst` | 988901454 | LCG.CNAF.it |  | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision18%2FLOG%2F00256909%2F0000&task_name=00003169) |
